@@ -21,11 +21,12 @@ example :
 
 from asyevent.event import Event
 from asyevent.event_manager import EventManager
-from asyevent.event_wrapper import EventWrapperMixin
+from asyevent.event_wrapper import EventWrapper
 from asyevent.callback import Callback
 from asyevent.command import Command
+from asyevent.utils.parser import IParsable
 
 
-__author__ = 'Zucchinetti Hervé'
-__status__ = 'In development'
-__version__ = '0.1.3'
+__author__ = "Zucchinetti Hervé"
+__status__ = "In development"
+__version__ = "0.2.1"
